@@ -20,16 +20,18 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-
 import string
+from typing import TypeVar, Generic, Tuple, Dict
+
+T = TypeVar("T")
 
 
-class KeyMap:
-    def __init__(self, default=""):
-        self.map = {}
+class KeyMap(Generic[T]):
+    def __init__(self, default: T) -> None:
+        self.map: Dict[str, T] = {}
         self.default = default
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> T:
         if not key:
             # Unbound key
             return self.default
@@ -40,26 +42,26 @@ class KeyMap:
                 f"Configured keymap ({key}) does not exist in bpython.keys"
             )
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: str) -> None:
         del self.map[key]
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: str, value: T) -> None:
         self.map[key] = value
 
 
-cli_key_dispatch = KeyMap(tuple())
+cli_key_dispatch: KeyMap[Tuple[str, ...]] = KeyMap(tuple())
 urwid_key_dispatch = KeyMap("")
 
 # fill dispatch with letters
 for c in string.ascii_lowercase:
-    cli_key_dispatch["C-%s" % c] = (
+    cli_key_dispatch[f"C-{c}"] = (
         chr(string.ascii_lowercase.index(c) + 1),
-        "^%s" % c.upper(),
+        f"^{c.upper()}",
     )
 
 for c in string.ascii_lowercase:
-    urwid_key_dispatch["C-%s" % c] = "ctrl %s" % c
-    urwid_key_dispatch["M-%s" % c] = "meta %s" % c
+    urwid_key_dispatch[f"C-{c}"] = f"ctrl {c}"
+    urwid_key_dispatch[f"M-{c}"] = f"meta {c}"
 
 # fill dispatch with cool characters
 cli_key_dispatch["C-["] = (chr(27), "^[")
@@ -70,7 +72,7 @@ cli_key_dispatch["C-_"] = (chr(31), "^_")
 
 # fill dispatch with function keys
 for x in range(1, 13):
-    cli_key_dispatch["F%d" % x] = ("KEY_F(%d)" % x,)
+    cli_key_dispatch[f"F{x}"] = (f"KEY_F({x})",)
 
 for x in range(1, 13):
-    urwid_key_dispatch["F%d" % x] = "f%d" % x
+    urwid_key_dispatch[f"F{x}"] = f"f{x}"
